/*
* @file    FT800_config.c
* @brief   Contains hardware abstraction functions for using the FT8xx
* @version 2.2
* @date    2016-04-23
* @author  Rudolph Riedel

2.2
- extracted from FT800_commands.c
- added ft800_pdn_set() and ft800_pdn_clear()
- replaced spi_flash_write() with fetch_flash_byte()

*/

#include "FT800_config.h"


#ifdef AVR8

#define FT_CS_PORT	PORTB
#define FT_CS 		(1<<PB4)
#define FT_PDN_PORT	PORTB
#define FT_PDN		(1<<PB5)


void ft800_cs_set(void)
{
	FT_CS_PORT &= ~FT_CS;	// cs low
}


void ft800_cs_clear(void)
{
	FT_CS_PORT |= FT_CS;	// cs high
}


void ft800_pdn_set(void)
{
	FT_PDN_PORT &= ~FT_PDN;	// Power-Down low
}


void ft800_pdn_clear(void)
{
	FT_PDN_PORT |= FT_PDN;	// Power-Down high
}


void spi_transmit(uint8_t data)
{
	SPDR = data; // Start transmission
	while(!(SPSR & (1<<SPIF))); // Wait for transmission to complete - 1s @ 8MHz SPI-Clock
}


uint8_t spi_receive(uint8_t data)
{
	SPDR = data; // Start transmission
	while(!(SPSR & (1<<SPIF))); // Wait for transmission to complete - 1s @ 8MHz SPI-CLock
	return SPDR;
}


uint8_t fetch_flash_byte(const uint8_t *data)
{
	return(pgm_read_byte_far(data));
}


#endif
